pub struct BulkReadResponse {
pub values: HashMap<String, NodeValueUpdate>,
}Expand description
Response to a nodes/bulk/read query.
values maps each requested node name to its current value + access_mode.
Node names not found in the store are omitted (not an error).
Fields
values: HashMap<String, NodeValueUpdate>Trait Implementations
Sourceimpl Clone for BulkReadResponse
impl Clone for BulkReadResponse
Sourcefn clone(&self) -> BulkReadResponse
fn clone(&self) -> BulkReadResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BulkReadResponse
impl Debug for BulkReadResponse
Sourceimpl<'de> Deserialize<'de> for BulkReadResponse
impl<'de> Deserialize<'de> for BulkReadResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more